@@ -68,7 +68,7 @@ pub mod prelude {
 }
 
 thread_local! {
-    static INPUT: RefCell<Option<String>> = Default::default();
+    static INPUT: RefCell<Option<&'static str>> = Default::default();
 }
 
 static OUT_CONTROL: AtomicI32 = AtomicI32::new(1);
@@ -76,8 +76,10 @@ static OUT_CONTROL: AtomicI32 = AtomicI32::new(1);
 pub fn bench_mode(path: impl AsRef<Path>) {
     OUT_CONTROL.store(0, Ordering::SeqCst);
     INPUT.with(|k| *k.borrow_mut() = Some(
-        std::fs::read_to_string(path.as_ref()).unwrap_or_else(
-            |e| panic!("could not read input file: {}", e))
+        Box::leak(
+            std::fs::read_to_string(path.as_ref()).unwrap_or_else(
+                |e| panic!("could not read input file: {}", e)).into()
+        )
     ));
 }
 
